===============================
File Helper Utils
===============================


Collection of exported functions for performing file-based tasks.


The following exported scripts are available:
----------------------------------------------

- calculate_md5
- check_indir_status
- check_infile_status
- check_outdir_status
- check_outfile_status
- get_file_creation_date
- get_file_list_from_directory
- get_file_size
- get_line_count
- is_binary_file


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
